@@ -136,7 +136,7 @@ AgentWidget::AgentWidget(QWidget *parent)
     ui.restartButton->setIcon(QIcon::fromTheme(QStringLiteral("system-reboot")));     //FIXME: Is using system-reboot icon here a good idea?
     connect(ui.restartButton, &QPushButton::clicked, this, &AgentWidget::restartAgent);
 
-    ui.mFilterAccount->setProxy(ui.instanceWidget->agentFilterProxyModel());
+    connect(ui.mFilterAccount, &QLineEdit::textChanged, ui.instanceWidget->agentFilterProxyModel(), &AgentFilterProxyModel::setFilterFixedString);
     ui.mFilterAccount->installEventFilter(this);
     ControlGui::widgetNeedsAkonadi(this);
 }
@@ -435,8 +435,8 @@ void AgentWidget::currentChanged()
             i18nc("Two statuses, for example \"Online, Running (66%)\" or \"Offline, Broken\"",
                   "%1, %2", onlineStatus, agentStatus));
         ui.statusMessageLabel->setText(instance.statusMessage());
-        ui.capabilitiesLabel->setText(instance.type().capabilities().join(QStringLiteral(", ")));
-        ui.mimeTypeLabel->setText(instance.type().mimeTypes().join(QStringLiteral(", ")));
+        ui.capabilitiesLabel->setText(instance.type().capabilities().join(QLatin1String(", ")));
+        ui.mimeTypeLabel->setText(instance.type().mimeTypes().join(QLatin1String(", ")));
     } else {
         ui.identifierLabel->setText(QString());
         ui.typeLabel->setText(QString());
